spannertools.Crescendo
======================

.. abjad-lineage:: abjad.tools.spannertools.Crescendo.Crescendo

.. autoclass:: abjad.tools.spannertools.Crescendo.Crescendo

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.Crescendo.Crescendo.append
      ~abjad.tools.spannertools.Crescendo.Crescendo.append_left
      ~abjad.tools.spannertools.Crescendo.Crescendo.components
      ~abjad.tools.spannertools.Crescendo.Crescendo.detach
      ~abjad.tools.spannertools.Crescendo.Crescendo.direction
      ~abjad.tools.spannertools.Crescendo.Crescendo.extend
      ~abjad.tools.spannertools.Crescendo.Crescendo.extend_left
      ~abjad.tools.spannertools.Crescendo.Crescendo.fracture
      ~abjad.tools.spannertools.Crescendo.Crescendo.fuse
      ~abjad.tools.spannertools.Crescendo.Crescendo.get_duration
      ~abjad.tools.spannertools.Crescendo.Crescendo.get_timespan
      ~abjad.tools.spannertools.Crescendo.Crescendo.include_rests
      ~abjad.tools.spannertools.Crescendo.Crescendo.index
      ~abjad.tools.spannertools.Crescendo.Crescendo.is_hairpin_shape_string
      ~abjad.tools.spannertools.Crescendo.Crescendo.is_hairpin_token
      ~abjad.tools.spannertools.Crescendo.Crescendo.leaves
      ~abjad.tools.spannertools.Crescendo.Crescendo.pop
      ~abjad.tools.spannertools.Crescendo.Crescendo.pop_left
      ~abjad.tools.spannertools.Crescendo.Crescendo.shape_string
      ~abjad.tools.spannertools.Crescendo.Crescendo.start_dynamic_string
      ~abjad.tools.spannertools.Crescendo.Crescendo.stop_dynamic_string
      ~abjad.tools.spannertools.Crescendo.Crescendo.__contains__
      ~abjad.tools.spannertools.Crescendo.Crescendo.__copy__
      ~abjad.tools.spannertools.Crescendo.Crescendo.__eq__
      ~abjad.tools.spannertools.Crescendo.Crescendo.__format__
      ~abjad.tools.spannertools.Crescendo.Crescendo.__getitem__
      ~abjad.tools.spannertools.Crescendo.Crescendo.__len__
      ~abjad.tools.spannertools.Crescendo.Crescendo.__lt__
      ~abjad.tools.spannertools.Crescendo.Crescendo.__ne__
      ~abjad.tools.spannertools.Crescendo.Crescendo.__repr__

Bases
-----

- :py:class:`spannertools.Hairpin <abjad.tools.spannertools.Hairpin.Hairpin>`

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.Crescendo.Crescendo.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Crescendo.Crescendo.leaves
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.spannertools.Crescendo.Crescendo.direction
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Crescendo.Crescendo.include_rests
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Crescendo.Crescendo.shape_string
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Crescendo.Crescendo.start_dynamic_string
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Crescendo.Crescendo.stop_dynamic_string
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.append
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.detach
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.get_duration
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.get_timespan
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.index
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.pop_left
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.is_hairpin_shape_string
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.is_hairpin_token
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.__format__
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.Crescendo.Crescendo.__repr__
   :noindex:
